CompressStarted

Struct CompressStarted 

pub struct CompressStarted<W> { /* private fields */ }

Implementations

Source

impl<W> CompressStarted<W>

pub fn write_marker(&mut self, marker: Marker, data: &[u8])

Add a marker to compressed file

Data is max 64KB

Panics

It may panic, like all functions of this library.

pub fn write_icc_profile(&mut self, data: &[u8])

Add ICC profile to compressed file

Panics

It may panic, like all functions of this library.

pub fn components(&self) -> &[CompInfo]

Read-only view of component information

Source

impl<W> CompressStarted<W>

pub fn write_scanlines(&mut self, image_src: &[u8]) -> Result<()>

Returns Ok(()) if all lines in image_src (not necessarily all lines of the image) were written

Panics

It may panic, like all functions of this library.

pub fn write_raw_data(&mut self, image_src: &[&[u8]]) -> bool

Advanced. Only possible after set_raw_data_in(). Write YCbCr blocks pixels instead of usual color space

See raw_data_in in libjpeg docs

Panic

Panics if raw write wasn’t enabled

Source

impl<W: Write> CompressStarted<W>

pub fn finish(self) -> Result<W>

Finalize compression. In case of progressive files, this may actually start processing.

Panics

It may panic, like all functions of this library.

pub fn abort(self) -> W

Give up writing, return incomplete result