pub struct CompressStarted<W> { /* private fields */ }Implementations
Sourceimpl<W> CompressStarted<W>
impl<W> CompressStarted<W>
Sourcepub fn write_marker(&mut self, marker: Marker, data: &[u8])
pub fn write_marker(&mut self, marker: Marker, data: &[u8])
Add a marker to compressed file
Data is max 64KB
Panics
It may panic, like all functions of this library.
Sourcepub fn write_icc_profile(&mut self, data: &[u8])
pub fn write_icc_profile(&mut self, data: &[u8])
Sourcepub fn components(&self) -> &[CompInfo]
pub fn components(&self) -> &[CompInfo]
Read-only view of component information
Sourceimpl<W> CompressStarted<W>
impl<W> CompressStarted<W>
Sourcepub fn write_scanlines(&mut self, image_src: &[u8]) -> Result<()>
pub fn write_scanlines(&mut self, image_src: &[u8]) -> Result<()>
Returns Ok(()) if all lines in image_src (not necessarily all lines of the image) were written
Panics
It may panic, like all functions of this library.
Sourcepub fn write_raw_data(&mut self, image_src: &[&[u8]]) -> bool
pub fn write_raw_data(&mut self, image_src: &[&[u8]]) -> bool
Advanced. Only possible after set_raw_data_in().
Write YCbCr blocks pixels instead of usual color space
See raw_data_in in libjpeg docs
Panic
Panics if raw write wasn’t enabled